#!/bin/bash
set -ex

API="2.2"
HEADERS="opencl.h cl_platform.h cl.h cl_ext.h cl_egl.h cl_dx9_media_sharing.h cl_d3d10.h cl_d3d11.h cl_gl.h cl_gl_ext.h cl_version.h cl_icd.h"
URL="https://raw.githubusercontent.com/KhronosGroup/OpenCL-Headers/master/CL/"

# OCL 1.2 compatibility
API2="2.1"
HEADERS2="cl.hpp"
URL2="https://www.khronos.org/registry/cl/api/$API2/"

# OCL 2.0 compatibility
API3="2.0"
HEADERS3="cl2.hpp"
URL3="https://github.com/KhronosGroup/OpenCL-CLHPP/releases/download/v$API3.10/"

WORKDIR="$(mktemp -d opengl.XXXX)"

TODIR="$(pwd)"
cd "$WORKDIR"

mkdir headers
cd headers

DATE=0
for file in $HEADERS; do
	wget "$URL/$file"
	FILEDATE="$(date -ud "@$(stat -c%Y "$file")" +%Y%m%d)"
	[ $FILEDATE -gt $DATE ] && DATE=$FILEDATE
done

# OCL 1.2 compatibility
for file in $HEADERS2; do
	wget "$URL2/$file"
done

# OCL 2.0 compatibility
for file in $HEADERS3; do
	wget "$URL3/$file"
done

cd ..

TARNAME="opencl-headers-$API-$DATE"
TAR="$TARNAME.tar.xz"
mv headers "$TARNAME"

if [ -e "$TODIR/$TAR" ]; then
	echo "$TAR already exists."
else
	tar -cJf "$TODIR/$TAR" "$TARNAME"
fi
cd "$TODIR"
rm -r "$WORKDIR"
